-- DROP TABLE BUSINESS_DESCR;
-- DROP TABLE BUSINESS_CATEGORY;
-- DROP TABLE BUSINESS_IDENTIFIER;
-- DROP TABLE BUSINESS_NAME;
-- DROP TABLE DISCOVERY_URL;
-- DROP TABLE ADDRESS_LINE;
-- DROP TABLE ADDRESS;
-- DROP TABLE PHONE;
-- DROP TABLE EMAIL;
-- DROP TABLE CONTACT_DESCR;
-- DROP TABLE CONTACT;
-- DROP TABLE SERVICE_DESCR;
-- DROP TABLE SERVICE_CATEGORY;
-- DROP TABLE SERVICE_NAME;
-- DROP TABLE BINDING_DESCR;
-- DROP TABLE BINDING_CATEGORY;
-- DROP TABLE INSTANCE_DETAILS_DESCR;
-- DROP TABLE INSTANCE_DETAILS_DOC_DESCR;
-- DROP TABLE TMODEL_CATEGORY;
-- DROP TABLE TMODEL_DESCR;
-- DROP TABLE TMODEL_DOC_DESCR;
-- DROP TABLE TMODEL_IDENTIFIER;
-- DROP TABLE TMODEL_INSTANCE_INFO_DESCR;
-- DROP TABLE TMODEL_INSTANCE_INFO;
-- DROP TABLE PUBLISHER_ASSERTION;
-- DROP TABLE TMODEL;
-- DROP TABLE BINDING_TEMPLATE;
-- DROP TABLE BUSINESS_SERVICE;
-- DROP TABLE BUSINESS_ENTITY;
-- DROP TABLE PUBLISHER;
-- DROP TABLE AUTH_TOKEN;

CREATE TABLE BUSINESS_ENTITY
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	AUTHORIZED_NAME VARCHAR(255) NOT NULL,
	PUBLISHER_ID VARCHAR(20) NULL,
	OPERATOR VARCHAR(255) NOT NULL,
	LAST_UPDATE TIMESTAMP NOT NULL DEFAULT now(),
	CONSTRAINT PK_BUSINESS_ENTITY PRIMARY KEY (BUSINESS_KEY)
);

CREATE TABLE BUSINESS_DESCR
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	BUSINESS_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_BUS_DESCR_01 FOREIGN KEY (BUSINESS_KEY)
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY) 
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BUSINESS_DESCR PRIMARY KEY (BUSINESS_KEY,BUSINESS_DESCR_ID)
);

CREATE TABLE BUSINESS_CATEGORY
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CATEGORY_ID INT NOT NULL,
	TMODEL_KEY_REF VARCHAR(41) NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	CONSTRAINT FK_BUS_CAT_01 FOREIGN KEY (BUSINESS_KEY)
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BUSINESS_CATEGORY PRIMARY KEY (BUSINESS_KEY,CATEGORY_ID)
);

CREATE TABLE BUSINESS_IDENTIFIER
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	IDENTIFIER_ID INT NOT NULL,
	TMODEL_KEY_REF VARCHAR(41) NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	CONSTRAINT FK_BUS_ID_01 FOREIGN KEY (BUSINESS_KEY)
	REFERENCES BUSINESS_ENTITY (BUSINESS_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BUSINESS_IDENTIFIER PRIMARY KEY (BUSINESS_KEY,IDENTIFIER_ID)
);

CREATE TABLE BUSINESS_NAME
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	BUSINESS_NAME_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	NAME VARCHAR(255) NOT NULL,
	CONSTRAINT FK_BUS_NAME_01 FOREIGN KEY (BUSINESS_KEY)
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BUSINESS_NAME PRIMARY KEY (BUSINESS_KEY,BUSINESS_NAME_ID)
);

CREATE TABLE CONTACT
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CONTACT_ID INT NOT NULL,
	USE_TYPE VARCHAR(255) NULL,
	PERSON_NAME VARCHAR(255) NOT NULL,
	CONSTRAINT FK_CONTACT_01 FOREIGN KEY (BUSINESS_KEY)
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_CONTACT PRIMARY KEY (BUSINESS_KEY,CONTACT_ID)
);

CREATE TABLE CONTACT_DESCR
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CONTACT_ID INT NOT NULL,
	CONTACT_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_CONTACT_DESCR_01 FOREIGN KEY (BUSINESS_KEY,CONTACT_ID)
		REFERENCES CONTACT (BUSINESS_KEY,CONTACT_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_CONTACT_DESCR PRIMARY KEY (BUSINESS_KEY,CONTACT_ID,CONTACT_DESCR_ID)
);

CREATE TABLE ADDRESS
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CONTACT_ID INT NOT NULL,
	ADDRESS_ID INT NOT NULL,
	USE_TYPE VARCHAR(255) NULL,
	SORT_CODE VARCHAR(10) NULL,
	TMODEL_KEY VARCHAR(41) NULL,
	CONSTRAINT FK_ADDRESS_01 FOREIGN KEY (BUSINESS_KEY,CONTACT_ID)
		REFERENCES CONTACT (BUSINESS_KEY,CONTACT_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_ADDRESS PRIMARY KEY (BUSINESS_KEY,CONTACT_ID,ADDRESS_ID)
);

CREATE TABLE ADDRESS_LINE
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CONTACT_ID INT NOT NULL,
	ADDRESS_ID INT NOT NULL,
	ADDRESS_LINE_ID INT NOT NULL,
	LINE VARCHAR(80) NOT NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NULL,
	CONSTRAINT FK_ADDR_LINE_01 FOREIGN KEY (BUSINESS_KEY,CONTACT_ID,ADDRESS_ID)
		REFERENCES ADDRESS (BUSINESS_KEY,CONTACT_ID,ADDRESS_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_ADDRESS_LINE PRIMARY KEY (BUSINESS_KEY,CONTACT_ID,ADDRESS_ID,ADDRESS_LINE_ID)
);

CREATE TABLE EMAIL
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CONTACT_ID INT NOT NULL,
	EMAIL_ID INT NOT NULL,
	USE_TYPE VARCHAR(255) NULL,
	EMAIL_ADDRESS VARCHAR(255) NOT NULL,
	CONSTRAINT FK_EMAIL_01 FOREIGN KEY (BUSINESS_KEY,CONTACT_ID)
		REFERENCES CONTACT (BUSINESS_KEY,CONTACT_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_EMAIL PRIMARY KEY (BUSINESS_KEY,CONTACT_ID,EMAIL_ID)
);

CREATE TABLE PHONE
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	CONTACT_ID INT NOT NULL,
	PHONE_ID INT NOT NULL,
	USE_TYPE VARCHAR(255) NULL,
	PHONE_NUMBER VARCHAR(50) NOT NULL,
	CONSTRAINT FK_PHONE_01 FOREIGN KEY (BUSINESS_KEY,CONTACT_ID)
		REFERENCES CONTACT (BUSINESS_KEY,CONTACT_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_PHONE PRIMARY KEY (BUSINESS_KEY,CONTACT_ID,PHONE_ID)
);

CREATE TABLE DISCOVERY_URL
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	DISCOVERY_URL_ID INT NOT NULL,
	USE_TYPE VARCHAR(255) NOT NULL,
	URL VARCHAR(255) NOT NULL,
	CONSTRAINT FK_DISCOVERY_URL_01 FOREIGN KEY (BUSINESS_KEY)
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_DISCOVERY_URL PRIMARY KEY (BUSINESS_KEY,DISCOVERY_URL_ID)
);

CREATE TABLE BUSINESS_SERVICE
(
	BUSINESS_KEY VARCHAR(41) NOT NULL,
	SERVICE_KEY VARCHAR(41) NOT NULL,
	LAST_UPDATE TIMESTAMP NOT NULL DEFAULT now(),
	CONSTRAINT FK_BUS_SERVICE_01 FOREIGN KEY (BUSINESS_KEY)
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BUSINESS_SERVICE PRIMARY KEY (SERVICE_KEY)
);

CREATE TABLE SERVICE_DESCR
(
	SERVICE_KEY VARCHAR(41) NOT NULL,
	SERVICE_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_SERVICE_DESCR_01 FOREIGN KEY (SERVICE_KEY)
		REFERENCES BUSINESS_SERVICE (SERVICE_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_SERVICE_DESCR PRIMARY KEY (SERVICE_KEY,SERVICE_DESCR_ID)
);

CREATE TABLE SERVICE_CATEGORY
(
	SERVICE_KEY VARCHAR(41) NOT NULL,
	CATEGORY_ID INT NOT NULL,
	TMODEL_KEY_REF VARCHAR(41) NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	CONSTRAINT FK_SERVICE_CATEGORY_01 FOREIGN KEY (SERVICE_KEY)
		REFERENCES BUSINESS_SERVICE (SERVICE_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_SERVICE_CATEGORY PRIMARY KEY (SERVICE_KEY,CATEGORY_ID)
);

CREATE TABLE SERVICE_NAME
(
	SERVICE_KEY VARCHAR(41) NOT NULL,
	SERVICE_NAME_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	NAME VARCHAR(255) NOT NULL,
	CONSTRAINT FK_SERVICE_NAME_01 FOREIGN KEY (SERVICE_KEY)
		REFERENCES BUSINESS_SERVICE (SERVICE_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_SERVICE_NAME PRIMARY KEY (SERVICE_KEY,SERVICE_NAME_ID)
);

CREATE TABLE BINDING_TEMPLATE
(
	SERVICE_KEY VARCHAR(41) NOT NULL,
	BINDING_KEY VARCHAR(41) NOT NULL,
	ACCESS_POINT_TYPE VARCHAR(20) NULL,
	ACCESS_POINT_URL VARCHAR(255) NULL,
	HOSTING_REDIRECTOR VARCHAR(255) NULL,
	LAST_UPDATE TIMESTAMP NOT NULL DEFAULT now(),
	CONSTRAINT FK_BINDING_TEMPLATE_01 FOREIGN KEY (SERVICE_KEY)
		REFERENCES BUSINESS_SERVICE (SERVICE_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BINDING_TEMPLATE PRIMARY KEY (BINDING_KEY)
);

CREATE TABLE BINDING_CATEGORY
(
	BINDING_KEY VARCHAR(41) NOT NULL,
	CATEGORY_ID INT NOT NULL,
	TMODEL_KEY_REF VARCHAR(41) NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	CONSTRAINT FK_BINDING_CATEGORY_01 FOREIGN KEY (BINDING_KEY)
		REFERENCES BINDING_TEMPLATE (BINDING_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BINDING_CATEGORY PRIMARY KEY (BINDING_KEY,CATEGORY_ID)
);


CREATE TABLE BINDING_DESCR
(
	BINDING_KEY VARCHAR(41) NOT NULL,
	BINDING_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_BINDING_DESCR_01 FOREIGN KEY (BINDING_KEY)
		REFERENCES BINDING_TEMPLATE (BINDING_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_BINDING_DESCR PRIMARY KEY (BINDING_KEY,BINDING_DESCR_ID)
);

CREATE TABLE TMODEL_INSTANCE_INFO
(
	BINDING_KEY VARCHAR(41) NOT NULL,
	TMODEL_INSTANCE_INFO_ID INT NOT NULL,
	TMODEL_KEY VARCHAR(41) NOT NULL,
	OVERVIEW_URL VARCHAR(255) NULL,
	INSTANCE_PARMS VARCHAR(255) NULL,
	CONSTRAINT FK_TMODEL_INSTANCE_INFO_01 FOREIGN KEY (BINDING_KEY)
		REFERENCES BINDING_TEMPLATE (BINDING_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_TMODEL_INSTANCE_INFO PRIMARY KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
);

CREATE TABLE TMODEL_INSTANCE_INFO_DESCR
(
	BINDING_KEY VARCHAR(41) NOT NULL,
	TMODEL_INSTANCE_INFO_ID INT NOT NULL,
	TMODEL_INSTANCE_INFO_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_TMODEL_INSTANCE_INFO_DESCR_01 FOREIGN KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
		REFERENCES TMODEL_INSTANCE_INFO (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_TMODEL_INSTANCE_INFO_DESCR PRIMARY KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID,TMODEL_INSTANCE_INFO_DESCR_ID)
);

CREATE TABLE INSTANCE_DETAILS_DESCR
(
	BINDING_KEY VARCHAR(41) NOT NULL,
	TMODEL_INSTANCE_INFO_ID INT NOT NULL,
	INSTANCE_DETAILS_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_INSTANCE_DETAILS_DESCR_01 FOREIGN KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
		REFERENCES TMODEL_INSTANCE_INFO (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_INSTANCE_DETAILS_DESCR PRIMARY KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID,INSTANCE_DETAILS_DESCR_ID)
);

CREATE TABLE INSTANCE_DETAILS_DOC_DESCR
(
	BINDING_KEY VARCHAR(41) NOT NULL,
	TMODEL_INSTANCE_INFO_ID INT NOT NULL,
	INSTANCE_DETAILS_DOC_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_INSTANCE_DETAILS_DOC_DESCR_01 FOREIGN KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
		REFERENCES TMODEL_INSTANCE_INFO (BINDING_KEY,TMODEL_INSTANCE_INFO_ID)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_INSTANCE_DETAILS_DOC_DESCR PRIMARY KEY (BINDING_KEY,TMODEL_INSTANCE_INFO_ID,INSTANCE_DETAILS_DOC_DESCR_ID)
);

CREATE TABLE TMODEL
(
	TMODEL_KEY VARCHAR(41) NOT NULL,
	AUTHORIZED_NAME VARCHAR(255) NOT NULL,
	PUBLISHER_ID VARCHAR(20) NULL,
	OPERATOR VARCHAR(255) NOT NULL,
	NAME VARCHAR(255) NOT NULL,
	OVERVIEW_URL VARCHAR(255) NULL,
    DELETED VARCHAR(5) NULL,
	LAST_UPDATE TIMESTAMP NOT NULL DEFAULT NOW(),
	CONSTRAINT PK_TMODEL PRIMARY KEY (TMODEL_KEY)
);

CREATE TABLE TMODEL_DESCR
(
	TMODEL_KEY VARCHAR(41) NOT NULL,
	TMODEL_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_TMODEL_DESCR_01 FOREIGN KEY (TMODEL_KEY)
		REFERENCES TMODEL (TMODEL_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_TMODEL_DESCR PRIMARY KEY (TMODEL_KEY,TMODEL_DESCR_ID)
);

CREATE TABLE TMODEL_CATEGORY
(
	TMODEL_KEY VARCHAR(41) NOT NULL,
	CATEGORY_ID INT NOT NULL,
	TMODEL_KEY_REF VARCHAR(255) NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	CONSTRAINT FK_TMODEL_CATEGORY_01 FOREIGN KEY (TMODEL_KEY)
		REFERENCES TMODEL (TMODEL_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_TMODEL_CATEGORY PRIMARY KEY (TMODEL_KEY,CATEGORY_ID)
);

CREATE TABLE TMODEL_IDENTIFIER
(
	TMODEL_KEY VARCHAR(41) NOT NULL,
	IDENTIFIER_ID INT NOT NULL,
	TMODEL_KEY_REF VARCHAR(255) NULL,
	KEY_NAME VARCHAR(255) NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	CONSTRAINT FK_TMODEL_IDENTIFIER_01 FOREIGN KEY (TMODEL_KEY)
		REFERENCES TMODEL (TMODEL_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_TMODEL_IDENTIFIER PRIMARY KEY (TMODEL_KEY,IDENTIFIER_ID)
);

CREATE TABLE TMODEL_DOC_DESCR
(
	TMODEL_KEY VARCHAR(41) NOT NULL,
	TMODEL_DOC_DESCR_ID INT NOT NULL,
	LANG_CODE VARCHAR(5) NULL,
	DESCR VARCHAR(255) NOT NULL,
	CONSTRAINT FK_TMODEL_DOC_DESCR_01 FOREIGN KEY (TMODEL_KEY)
		REFERENCES TMODEL (TMODEL_KEY)
		ON UPDATE CASCADE ON DELETE CASCADE,
	CONSTRAINT PK_TMODEL_DOC_DESCR PRIMARY KEY (TMODEL_KEY,TMODEL_DOC_DESCR_ID)
);

CREATE TABLE PUBLISHER_ASSERTION
(
	FROM_KEY VARCHAR(41) NOT NULL,
	TO_KEY VARCHAR(41) NOT NULL,
	TMODEL_KEY VARCHAR(41) NOT NULL,
	KEY_NAME VARCHAR(255) NOT NULL,
	KEY_VALUE VARCHAR(255) NOT NULL,
	FROM_CHECK VARCHAR(5) NOT NULL,
	TO_CHECK VARCHAR(5) NOT NULL,
	CONSTRAINT FK_PUBLISHER_ASSERTION_01 FOREIGN KEY (FROM_KEY) 
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY),
	CONSTRAINT FK_PUBLISHER_ASSERTION_02 FOREIGN KEY (TO_KEY) 
		REFERENCES BUSINESS_ENTITY (BUSINESS_KEY),
	CONSTRAINT PK_PUBLISHER_ASSERTION PRIMARY KEY (FROM_KEY,TO_KEY)
);

CREATE TABLE PUBLISHER
(
	PUBLISHER_ID VARCHAR(20) NOT NULL,
	PUBLISHER_NAME VARCHAR(255) NOT NULL,
	EMAIL_ADDRESS VARCHAR(255) NULL,
	IS_ADMIN VARCHAR(5) NULL,
	IS_ENABLED VARCHAR(5) NULL,
	CONSTRAINT PK_PUBLISHER PRIMARY KEY (PUBLISHER_ID)
);

CREATE TABLE AUTH_TOKEN
(
	AUTH_TOKEN VARCHAR(51) NOT NULL,
	PUBLISHER_ID VARCHAR(20) NOT NULL,
	PUBLISHER_NAME VARCHAR(255) NOT NULL,
	CREATED TIMESTAMP NOT NULL,
	LAST_USED TIMESTAMP NOT NULL,
	NUMBER_OF_USES INT NOT NULL,
	TOKEN_STATE INT NOT NULL,
	CONSTRAINT PK_AUTH_TOKEN PRIMARY KEY (AUTH_TOKEN)
);

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','Administrator','jUDDI.org','uddi-org:types','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#UDDItypes');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4',0,'en','UDDI Type Taxonomy');
 
INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4',0,'en','Taxonomy used to categorize Service Descriptions.');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:DB77450D-9FA8-45D4-A7BC-04411D14E384','Administrator','jUDDI.org','unspsc-org:unspsc:3-1','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#UNSPSC31');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:DB77450D-9FA8-45D4-A7BC-04411D14E384',0,'en','Product Taxonomy: UNSPSC (Version 3.1)');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:DB77450D-9FA8-45D4-A7BC-04411D14E384',0,'en','This tModel defines the UNSPSC product taxonomy.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:DB77450D-9FA8-45D4-A7BC-04411D14E384',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:CD153257-086A-4237-B336-6BDCBDCC6634','Administrator','jUDDI.org','unspsc-org:unspsc','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#UNSPSC');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:CD153257-086A-4237-B336-6BDCBDCC6634',0,'en','Product Taxonomy: UNSPSC (Version 7.3)');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:CD153257-086A-4237-B336-6BDCBDCC6634',0,'en','This tModel defines Version 7.3 of the UNSPSC product taxonomy.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:CD153257-086A-4237-B336-6BDCBDCC6634',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:CD153257-086A-4237-B336-6BDCBDCC6634',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','Checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:C0B9FE13-179F-413D-8A5B-5004DB8E5BB2','Administrator','jUDDI.org','ntis-gov:naics:1997','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#NAICS');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:C0B9FE13-179F-413D-8A5B-5004DB8E5BB2',0,'en','Business Taxonomy: NAICS(1997 Release)');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:C0B9FE13-179F-413D-8A5B-5004DB8E5BB2',0,'en','This tModel defines the NAICS industry taxonomy.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:C0B9FE13-179F-413D-8A5B-5004DB8E5BB2',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:C0B9FE13-179F-413D-8A5B-5004DB8E5BB2',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:4E49A8D6-D5A2-4FC2-93A0-0411D8D19E88','Administrator','jUDDI.org','uddi-org:iso-ch:3166-1999','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#ISO3166');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:4E49A8D6-D5A2-4FC2-93A0-0411D8D19E88',0,'en','ISO 3166-1:1997 and 3166-2:1998. Codes for names of countries and their subdivisions. Part 1: Country codes. Part 2:Country subdivision codes. Update newsletters include ISO 3166-1 V-1 (1998-02-05), V-2 (1999-10-01), ISO 3166-2 I-1 (1998)');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:4E49A8D6-D5A2-4FC2-93A0-0411D8D19E88',0,'en','Taxonomy used to categorize entries by geographic location.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:4E49A8D6-D5A2-4FC2-93A0-0411D8D19E88',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:4E49A8D6-D5A2-4FC2-93A0-0411D8D19E88',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:A035A07C-F362-44DD-8F95-E2B134BF43B4','Administrator','jUDDI.org','uddi-org:general_keywords','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#GenKW');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:A035A07C-F362-44DD-8F95-E2B134BF43B4',0,'en','Special taxonomy consisting of namespace identifiers and the keywords associated with the namespaces');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:A035A07C-F362-44DD-8F95-E2B134BF43B4',0,'en','This tModel defines an unidentified taxonomy.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:A035A07C-F362-44DD-8F95-E2B134BF43B4',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:4064C064-6D14-4F35-8953-9652106476A9','Administrator','jUDDI.org','uddi-org:owningBusiness','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#owningBusiness');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:4064C064-6D14-4F35-8953-9652106476A9',0,'en','A pointer to a businessEntity that owns the tagged data.');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:4064C064-6D14-4F35-8953-9652106476A9',0,'en','This tModel indicates the businessEntity that published or owns the tagged tModel. Used with tModels to establish an "owned" relationship with a registered businessEntity.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:4064C064-6D14-4F35-8953-9652106476A9',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:4064C064-6D14-4F35-8953-9652106476A9',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:807A2C6A-EE22-470D-ADC7-E0424A337C03','Administrator','jUDDI.org','uddi-org:relationships','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#Relationships');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:807A2C6A-EE22-470D-ADC7-E0424A337C03',0,'en','Starter set classifications of businessEntity relationships');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:807A2C6A-EE22-470D-ADC7-E0424A337C03',0,'en','This tModel is used to describe business relationships. Used in the publisher assertion messages.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:807A2C6A-EE22-470D-ADC7-E0424A337C03',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','relationship');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:327A56F0-3299-4461-BC23-5CD513E95C55','Administrator','jUDDI.org','uddi-org:operators','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#Operators');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:327A56F0-3299-4461-BC23-5CD513E95C55',0,'en','Taxonomy for categorizing the businessEntity of an operator of a registry.');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:327A56F0-3299-4461-BC23-5CD513E95C55',0,'en','This checked value set is used to identify UDDI operators.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:327A56F0-3299-4461-BC23-5CD513E95C55',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:327A56F0-3299-4461-BC23-5CD513E95C55',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:E59AE320-77A5-11D5-B898-0004AC49CC1E','Administrator','jUDDI.org','uddi-org:isReplacedBy','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#IsReplacedBy');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:E59AE320-77A5-11D5-B898-0004AC49CC1E',0,'en','An identifier system used to point (using UDDI keys) to the tModel (or businessEntity) that is the logical replacement for the one in which isReplacedBy is used');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:E59AE320-77A5-11D5-B898-0004AC49CC1E',0,'en','This is a checked value set.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:E59AE320-77A5-11D5-B898-0004AC49CC1E',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','identifier');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:E59AE320-77A5-11D5-B898-0004AC49CC1E',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:8609C81E-EE1F-4D5A-B202-3EB13AD01823','Administrator','jUDDI.org','dnb-com:D-U-N-S','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#D-U-N-S');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:8609C81E-EE1F-4D5A-B202-3EB13AD01823',0,'en','Dun&Bradstreet D-U-N-S Number');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:8609C81E-EE1F-4D5A-B202-3EB13AD01823',0,'en','This tModel is used for the Dun&Bradstreet D-U-N-S Number identifier.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:8609C81E-EE1F-4D5A-B202-3EB13AD01823',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','identifier');

INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:B1B1BAF5-2329-43E6-AE13-BA8E97195039','Administrator','jUDDI.org','thomasregister-com:supplierID','http://www.uddi.org/taxonomies/UDDI_Taxonomy_tModels.htm#Thomas');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:B1B1BAF5-2329-43E6-AE13-BA8E97195039',0,'en','Thomas Registry Suppliers');

INSERT INTO TMODEL_DOC_DESCR (TMODEL_KEY,TMODEL_DOC_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:B1B1BAF5-2329-43E6-AE13-BA8E97195039',0,'en','This tModel is used for the Thomas Register supplier identifier codes.');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:B1B1BAF5-2329-43E6-AE13-BA8E97195039',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','identifier');

----- End Standard Stuff -----

-- WSDL Address Model
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:AD61DE98-4DB8-31B2-A299-A2373DC97212','Administrator','jUDDI.org','uddi-org:wsdl:address','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#Address');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:AD61DE98-4DB8-31B2-A299-A2373DC97212',0,'en','A tModel used to indicate the WSDL address option');
 
-- Transport Categorization
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:E5C43936-86E4-37BF-8196-1D04B35C0099','Administrator','jUDDI.org','uddi-org:wsdl:categorization:transport','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#transport');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:E5C43936-86E4-37BF-8196-1D04B35C0099',0,'en','Category system used to describe the protocol supported by a wsdl:binding.');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:E5C43936-86E4-37BF-8196-1D04B35C0099',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:E5C43936-86E4-37BF-8196-1D04B35C0099',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

-- Protocol Categorization
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:4DC74177-7806-34D9-AECD-33C57DC3A865','Administrator','jUDDI.org','uddi-org:wsdl:categorization:protocol','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#protocol');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:4DC74177-7806-34D9-AECD-33C57DC3A865',0,'en','Category system used to describe the protocol supported by a wsdl:binding.');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:4DC74177-7806-34D9-AECD-33C57DC3A865',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:4DC74177-7806-34D9-AECD-33C57DC3A865',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

-- HTTP Protocol TModel
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:6E10B91B-BABC-3442-B8FC-5A3C8FDE0794','Administrator','jUDDI.org','uddi.org:protocol:http','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#http');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:6E10B91B-BABC-3442-B8FC-5A3C8FDE0794',0,'en','A tModel that represents the HTTP protocol.');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:6E10B91B-BABC-3442-B8FC-5A3C8FDE0794',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','protocol');

-- SOAP 1.1 Protocol TModel
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:AA254698-93DE-3870-8DF3-A5C075D64A0E','Administrator','jUDDI.org','uddi.org:protocol:soap','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#soap');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:AA254698-93DE-3870-8DF3-A5C075D64A0E',0,'en','A tModel that represents the SOAP 1.1 protocol');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:AA254698-93DE-3870-8DF3-A5C075D64A0E',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','protocol');

-- portType reference
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:082B0851-25D8-303C-B332-F24A6D53E38E','Administrator','jUDDI.org','uddi.org:wsdl:portTypeReference','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#portTypeReference');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:082B0851-25D8-303C-B332-F24A6D53E38E',0,'en','A category system used to reference a wsdl:portType tModel');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:082B0851-25D8-303C-B332-F24A6D53E38E',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','checked');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:082B0851-25D8-303C-B332-F24A6D53E38E',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

-- local name tmodel
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:2EC65201-9109-3919-9BEC-C9DBEFCACCF6','Administrator','jUDDI.org','uddi.org:xml:localName','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#xmlLocalName');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:2EC65201-9109-3919-9BEC-C9DBEFCACCF6',0,'en','A category system used to indicate XML local names.');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:2EC65201-9109-3919-9BEC-C9DBEFCACCF6',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','unchecked');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:2EC65201-9109-3919-9BEC-C9DBEFCACCF6',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

-- namespace tmodel
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:D01987D1-AB2E-3013-9BE2-2A66EB99D824','Administrator','jUDDI.org','uddi-org:xml:namespace','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#xmlNamespace');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:D01987D1-AB2E-3013-9BE2-2A66EB99D824',0,'en','A category system used to indicate namespaces.');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:D01987D1-AB2E-3013-9BE2-2A66EB99D824',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','unchecked');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:D01987D1-AB2E-3013-9BE2-2A66EB99D824',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

-- the following 4 inserts deal with the "category" tModels included with each portType, binding, service,
-- and port tModel inserted.  (Each value for the Keyed Reference is from the portType, binding, etc set.)
INSERT INTO TMODEL (TMODEL_KEY,AUTHORIZED_NAME,OPERATOR,NAME,OVERVIEW_URL)
VALUES ('uuid:6E090AFA-33E5-36EB-81B7-1CA18373F457','Administrator','jUDDI.org','uddi-org:wsdl:types','http://www.oasis-open.org/committees/uddi-spec/doc/tn/uddi-spec-tc-tn-wsdl-v2.htm#wsdlTypes');

INSERT INTO TMODEL_DESCR (TMODEL_KEY,TMODEL_DESCR_ID,LANG_CODE,DESCR)
VALUES ('uuid:6E090AFA-33E5-36EB-81B7-1CA18373F457',0,'en','WSDL to UDDI Type Taxonomy');
 
INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:6E090AFA-33E5-36EB-81B7-1CA18373F457',0,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','unchecked');

INSERT INTO TMODEL_CATEGORY (TMODEL_KEY,CATEGORY_ID,TMODEL_KEY_REF,KEY_NAME,KEY_VALUE)
VALUES ('uuid:6E090AFA-33E5-36EB-81B7-1CA18373F457',1,'uuid:C1ACF26D-9672-4404-9D70-39B756E62AB4','types','categorization');

